@@ -62,9 +62,6 @@ namespace clad {
         : derivative(p_derivative), overload(p_overload) {}
   };
 
-  using VectorOutputs =
-      std::vector<std::unordered_map<const clang::ValueDecl*, clang::Expr*>>;
-
   static clang::SourceLocation noLoc{};
   class VisitorBase;
   /// The main builder class which then uses either ForwardModeVisitor or
@@ -107,6 +104,8 @@ namespace clad {
     /// overload to be found.
     /// \param[in] CallArgs The call args to be used to resolve to the
     /// correct overload.
+    /// \param[in] callSite - The call expression which triggers the custom
+    ///            derivative call.
     /// \param[in] forCustomDerv A flag to keep track of which
     /// namespace we should look in for the overloads.
     /// \param[in] namespaceShouldExist A flag to enforce assertion failure
@@ -117,8 +116,9 @@ namespace clad {
     /// null otherwise.
     clang::Expr* BuildCallToCustomDerivativeOrNumericalDiff(
         const std::string& Name, llvm::SmallVectorImpl<clang::Expr*>& CallArgs,
-        clang::Scope* S, clang::DeclContext* originalFnDC,
-        bool forCustomDerv = true, bool namespaceShouldExist = true);
+        clang::Scope* S, const clang::Expr* callSite, bool forCustomDerv = true,
+        bool namespaceShouldExist = true,
+        clang::Expr* CUDAExecConfig = nullptr);
     bool noOverloadExists(clang::Expr* UnresolvedLookup,
                           llvm::MutableArrayRef<clang::Expr*> ARargs);
     /// Shorthand to issues a warning or error.
@@ -133,6 +133,35 @@ namespace clad {
         stream << arg;
     }
 
+    /// Lookup the result of finding a custom derivative or numerical
+    /// differentiation function.
+    ///
+    /// \param[in] Name The name of the function to look up.
+    /// \param[in] originalFnDC The original function's DeclContext.
+    /// \param[in] SS The CXXScopeSpec to extend with the namespace of the
+    /// function.
+    /// \param[in] forCustomDerv A flag to keep track of which
+    /// namespace we should look in for the overloads.
+    /// \param[in] namespaceShouldExist A flag to enforce assertion failure
+    /// if the overload function namespace was not found. If false and
+    /// the function containing namespace was not found, nullptr is returned.
+    ///
+    /// \returns The lookup result of the custom derivative or numerical
+    /// differentiation function.
+    clang::LookupResult LookupCustomDerivativeOrNumericalDiff(
+        const std::string& Name, const clang::DeclContext* originalFnDC,
+        clang::CXXScopeSpec& SS, bool forCustomDerv = true,
+        bool namespaceShouldExist = true);
+
+    /// Looks up if the user has defined a custom derivative for the given
+    /// derivative function.
+    /// \param[in] D
+    /// \returns The custom derivative function if found, nullptr otherwise.
+    clang::FunctionDecl*
+    LookupCustomDerivativeDecl(const std::string& Name,
+                               const clang::DeclContext* originalFnDC,
+                               clang::QualType functionType);
+
   public:
     DerivativeBuilder(clang::Sema& S, plugin::CladPlugin& P,
                       DerivedFnCollector& DFC,
@@ -175,7 +204,16 @@ namespace clad {
     /// graph.
     ///
     /// \param[in] request The request to add the edge to.
-    void AddEdgeToGraph(const DiffRequest& request);
+    /// \param[in] alreadyDerived A flag to keep track of whether the request
+    /// is already derived or not.
+    void AddEdgeToGraph(const DiffRequest& request,
+                        bool alreadyDerived = false);
+
+    /// Handles processing of a diff request when an existing derivative is
+    /// being processed.
+    /// \param[in] Request The request to be processed.
+    /// \returns The derivative function if found, nullptr otherwise.
+    clang::FunctionDecl* HandleNestedDiffRequest(DiffRequest& request);
   };
 
 } // end namespace clad
