@@ -32,8 +32,6 @@
 #include "etc/dictpch/math/vecops/inc/LinkDef.h"
 #include "etc/dictpch/hist/hist/inc/LinkDef.h"
 #include "etc/dictpch/hist/histpainter/inc/LinkDef.h"
-#include "etc/dictpch/hist/histv7/inc/LinkDef.h"
-#include "etc/dictpch/hist/histdrawv7/inc/LinkDef.h"
 #include "etc/dictpch/hist/spectrum/inc/LinkDef.h"
 #include "etc/dictpch/hist/spectrumpainter/inc/LinkDef.h"
 #include "etc/dictpch/hist/hbook/inc/LinkDef.h"
